PyXMake Developer Guide: PyXMake.VTL.java Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Functions | Variables
PyXMake.VTL.java Namespace Reference

## Functions
def | main (BuildID, files=VTL.GetSourceCode(0), command=VTL.GetBuildCommand(1), libs=VTL.GetLinkDependency(0, 1, __arch), source=os.path.join(__mcd_core_path,"src"), include=[os.path.join(__mcd_core_path,"include", Utility.GetPlatform(), __arch, x) for x in VTL.GetIncludeDirectory(__mcd_core_path, 0, 4, __arch)], dependency=os.path.join(__mcd_core_path,"lib", Utility.GetPlatform(), __arch), output=os.path.join(__mcd_core_path,"bin", Utility.GetPlatform(), __arch), architecture=__arch, scratch=VTL.Scratch, verbosity=2)

## Variables
| parser = argparse.ArgumentParser(description="Build a static Fortran library remotely on the institute cluster")
| metavar
| nargs
| help
| args
| make_opt = args.make[0]
string | BuildID = 'bbeam_java';
| files
| source
| include
| dependency
| libs

## Detailed Description

    Triple-use minimum working example for PyXMake. This script can be
    executed in three different ways in varying levels of accessibility

    @note: Compile the BoxBeam & MCODAC for Java applications
                 using Intel Fortran and Java Native Access (JNA)
    Created on 20.03.2018

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake

    @change:
          -

    @author: garb_ma                                                     [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

def PyXMake.VTL.java.main | ( |  | BuildID,
|  |  | files = `VTL.GetSourceCode(0)`,
|  |  | command = `VTL.GetBuildCommand(1)`,
|  |  | libs = `VTL.GetLinkDependency(0, 1, __arch)`,
|  |  | source = `os.path.join(__mcd_core_path,"src")`,
|  |  | include = `[os.path.join(__mcd_core_path,"include",Utility.GetPlatform(),__arch, x) for x in VTL.GetIncludeDirectory(__mcd_core_path, 0, 4, __arch)]`,
|  |  | dependency = `os.path.join(__mcd_core_path,"lib",Utility.GetPlatform(),__arch)`,
|  |  | output = `os.path.join(__mcd_core_path,"bin",Utility.GetPlatform(),__arch)`,
|  |  | architecture = `__arch`,
|  |  | scratch = `VTL.Scratch`,
|  |  | verbosity = `2`
| ) |  |

    Main function to execute the script.

Definition at line 65 of file java.py.